@@ -94,7 +94,7 @@ class CentralReachRequestsCore:
 
     @retry_if_bad_request
     def _login_to_central_reach(self, login: str, password: str) -> None:
-        central_reach_core = CentralReachCore(login, password)
+        central_reach_core = CentralReachCore(login, password, headless=True)
         central_reach_core.login_to_site()
 
         # Check authorisation
